// VinciaHooks.h is a part of the VINCIA plug-in to the PYTHIA 8 generator.
// Copyright (C) 2016 P. Skands.
// VINCIA is licenced under the GNU GPL version 2.
// Please respect the MCnet Guidelines for Event Generator Authors and Users, 
//               http://www.montecarlonet.org/GUIDELINES

// This file contains header information for the VinciaHooks class .
// Added by NF to veto events in case of two event samples (for 
// hard jets in non-QCD processes)
  
#ifndef VINCIAVinciaHooks_H
#define VINCIAVinciaHooks_H

#include "Pythia8/UserHooks.h"
#include "Vincia/VinciaCommon.h"

namespace Vincia {
  
  //**************************************************************************

  // UserHooks that are used in the ISR shower to veto events
  
  class VinciaVetoHooks : public UserHooks {
    
  public:
    
    // Constructor.
    VinciaVetoHooks() : doVeto(false) {
    };
  
    // Destructor.
    virtual ~VinciaVetoHooks() { };
    
    // Start resonance showers at m
    virtual bool canSetResonanceScale() { return true; }
    virtual double scaleResonance(int iRes, const Event& event) {
      return event[iRes].m();
    }
    
    // Veto events (for the two event samples in non QCD processes)
    virtual bool canVetoStep() { return true; }
    virtual int numberVetoStep() { return 1; }
    // iPos = 0: no emissions so far
    // iPos = 1/2/3 joint evolution, latest step was MPI/ISR/FSR
    // iPos = 4: FSR only afterwards
    // iPos = 5: FSR in resonance decay
    virtual bool doVetoStep(int /*iPos*/, int /*nISR*/, int /*nFSR*/, 
                    const Event& /*event*/) {
      return doVeto;
    }
    // Do we want to veto the event?
    bool doVeto;
    
  };

  
}

#endif
