// VinciaRootSettings.h is a part of the VINCIA plug-in to the PYTHIA 8 generator.
// Copyright (C) 2016 P. Skands
// VINCIA is licenced under the GNU GPL version 2.
// Please respect the MCnet Guidelines for Event Generator Authors and Users, 
//               http://www.montecarlonet.org/GUIDELINES

// This file contains header information for the Vincia ROOT utilities

#ifndef VINCIAROOTSETTINGS_H
#define VINCIAROOTSETTINGS_H

// Include specific ROOT headers 

// Main ROOT header
#include "TROOT.h"
// 1D and 2D histograms
#include "TH1.h"
#include "TH2.h"
#include "TPaveStats.h"
// Graphs and Graphics
#include "TColor.h"
#include "TGraphAsymmErrors.h"
#include "TLine.h"
#include "TStyle.h"
// LaTeX, Text, and Legends
#include "TLatex.h"
#include "TLegend.h"
#include "TLegendEntry.h"
// Widget windows
#include "TCanvas.h"
#include "TApplication.h"
// To read/write files
#include "TDirectory.h"
#include "TFile.h"

// Standard Libraries (same as in PYTHIA 8)
// Stdlib header files for mathematics.
#include <cmath>
#include <cstdlib>

// Stdlib header files for strings and containers.
#include <string>
#include <vector>
#include <map>
#include <deque>
#include <set>

// Stdlib header file for input and output.
#include <iostream>
#include <iomanip>
#include <fstream>
#include <sstream>

// Define pi if not yet done.
#ifndef M_PI
#define M_PI 3.1415926535897932385
#endif

// Put all the rest in Vincia namespace

namespace Vincia {
  
  // Include the std namespace while inside the Vincia namespace.
  using namespace std;

  // ------------------------------------------------------------------------
  // class VRsettings
  // Contains global settings for the VinciaRoot interface

  class VRsettings {

  public:

    // Constructor
    VRsettings() : isInitApp(false), logY(false),  logX(false), 
      normalize(true), showRatioPad(true), showRelUncPads(true), 
      hasLeftLabel(false), hasRightLabel(false), 
      rebinLikeData(false), zeroSkipping(false), 
      showLegendChi2(true), 
      verbose(1), optStat(0), sigmaStat(1.), normFac(1.),
      ratioMin(0.5), ratioMax(1.5),
      MCnames(" "), signature("V I N C I A R O O T") { 
      legend.resize(0); 
      logY = false;
      logX = false;
      // Default plot sizes
      plotSizeX = 360;
      plotSizeY = 420;
      // Default uncertainty variation names = VINCIA ones
      legendUncVar.resize(0);
      legendUncVar.push_back(string("DEF"));
      legendUncVar.push_back(string("#alphaS#font[122]{+}"));
      legendUncVar.push_back(string("#alphaS#font[122]{-}"));
      legendUncVar.push_back(string("ANT#font[122]{+}"));
      legendUncVar.push_back(string("ANT#font[122]{-}"));
      legendUncVar.push_back(string("NLO#font[122]{+}"));
      legendUncVar.push_back(string("NLO#font[122]{-}"));
      legendUncVar.push_back(string("ORDPT"));
      legendUncVar.push_back(string("ORDMD"));
      legendUncVar.push_back(string("NLC#font[122]{+}"));
      legendUncVar.push_back(string("NLC#font[122]{-}"));
    };
    
    // Data members
    bool isInitApp;
    bool logY, logX, normalize;
    bool showRatioPad, showRelUncPads;
    bool hasLeftLabel, hasRightLabel;
    bool rebinLikeData, zeroSkipping;
    bool showLegendChi2;
    int verbose, optStat;
    double sigmaStat, normFac, ratioMin, ratioMax;
    double plotSizeX, plotSizeY;
    string MCnames, signature, leftLabel, rightLabel;    
    vector<string> legend;
    vector<string> legendUncVar;

  };
  
}

#endif
