#!/bin/bash
# script to convert a madgraph matrix.f file to unique naming convention
# for use with VINCIA. Also comments out spin average and Bose factors.
# Note: the nexternal.inc must already have been inserted in the matrix.f
mgfile=matrix.f
if [ $# = 1 ]; then
  mgfile=$1
fi
mgfigs=matrix.ps
if [ -r $mgfile ] && [ -r nexternal.inc ] ; then 
    pro=`grep -m1 "FOR PROCESS" $mgfile | cut -d":" -f2`
    is=`echo $pro | cut -d">" -f1 | sed s/"+"/x/g | sed s/"~"/x/g | sed s/"-"//g | sed s/" "//g`
    fs=`echo $pro | cut -d">" -f2 |  sed s/"+"/x/g | sed s/"~"/x/g | sed s/"-"//g | sed s/" "//g`
    echo IN: $is   OUT: $fs
    nd=$((`echo $fs | sed 's/[^d]//g'|wc -m`-1))
    nu=$((`echo $fs | sed 's/[^u]//g'|wc -m`-1))
    ng=$((`echo $fs | sed 's/[^g]//g'|wc -m`-1))
    name=${is}2${fs}
# Modify MadGraph file to be used in VINCIA. 
    date=`date`    
    (echo "C...${name}.f is a part of the VINCIA event generator."; echo "C...This file was generated by MADGRAPH 4"; echo "C...Modified by VINCIA ${date}"; echo "C...VINCIA is licenced under the GNU GPL version 2.";  echo "C...Copyright (C) 2015 Peter Skands"; echo "C...Please respect the work of the MadGraph authors by citing MadGraph 4 when"; echo "C...this part of VINCIA is used."; echo " "; cat $mgfile | sed s/MATRIX\(/MATRIX\(MCMODE\,ICOL\,/g | sed s/'      MATRIX = 0.D0'/'C...VINCIA: Leading Color for Diagonal Entry ICOL\
      MATRIX = CF\(ICOL\,ICOL\)\*JAMP\(ICOL\)\*DCONJG\(JAMP\(ICOL\)\)\/DENOM\(ICOL\)\
C...VINCIA: Absorb subleading color proportional to FSLC = LC\/Sum\(LC\)\
      IF \(MATRIX.GT.ZERO.AND.MCMODE.GE.1\) THEN\
        ZLCSUM = 0D0\
        DO I = 1\, NCOLOR\
          ZLCSUM = ZLCSUM + CF\(I\,I\)\*JAMP\(I\)\*DCONJG\(JAMP\(I\)\)\/DENOM\(I\)\
        ENDDO\
C...VINCIA: MCMODE = 2 returns full colour-summed ME\
        IF (MCMODE.EQ.2) MATRIX = ZLCSUM\
C...VINCIA: Fraction of subleading color to absorb into this permutation\
        FSLC = MATRIX\/ZLCSUM\
C...VINCIA: Sum over subleading contributions multiplied by FSLC'/g | sed s/"ZTEMP = ZTEMP"/"IF (I.NE.J) ZTEMP = ZTEMP"/ | sed s/"ZTEMP\*DCONJ"/"FSLC\*ZTEMP\*DCONJ"/ | sed 's/C      CALL GAUGE/      ENDIF\
C      CALL GAUGE/' | sed s/"         ANS(IPROC)="/"         ANS(IPROC) = "/ | sed s/"      ANS(IPROC)=ANS(IPROC)"/'\
C...VINCIA: Do not include spin average and Bose factor\
C      ANS(IPROC)=ANS(IPROC)'/ | sed 's/(ZERO=0D0)/(ZERO=0D0)\
      DOUBLE PRECISION ZLCSUM, FSLC/' | sed '/(MCMODE,P1,ANS)/ i\
C...VINCIA: Include helicity information\
' | sed s/'(MCMODE,ICOL,P1,ANS)'/'(MCMODE,ICOL,P1,HEL1,ANS)'/ | sed '/P1(0:3,NEXTERNAL),ANS(NCROSS)/ i\
C...VINCIA: Define HEL1 variable\
\      INTEGER HEL1(4)\
' | sed '/          DO IHEL=1,NCOMB/ a\
C...VINCIA: If spin-dependent, only compute amplitudes in HEL1\
C...VINCIA: (up to four IHELs can be contained in HEL1)\
\            IF (HEL1(1).LE.0.OR.IHEL.EQ.HEL1(1).OR.IHEL.EQ.HEL1(2)\
\     &          .OR.IHEL.EQ.HEL1(3).OR.IHEL.EQ.HEL1(4)) THEN\
\              T=MATRIX(MCMODE,ICOL,P,NHEL(1,IHEL),JC(1))\
\              ANS(IPROC) = ANS(IPROC)+T\
\            ENDIF\
' | sed s/'             IF (GOODHEL(IHEL,IPROC) .OR. NTRY .LT. 2) THEN'/'C...VINCIA: get rid of extra GOODHEL stuff\
\             IF (.FALSE.) THEN'/ | sed s/'.NOT.  '/'.NOT.'/ | sed s/MATRIX/${name}/g | sed s/switchmom/mo${name}/g | sed s/SWITCHMOM/mo${name}/g | sed s/"REAL\*8"/"DOUBLE PRECISION"/g | sed s/"integer    nexternal"/"integer    nexternal\, MCMODE\, ICOL"/ )> $name.f
    mv $mgfigs $name.ps
    gzip $name.ps
    echo $0: $mgfile
    echo $0: "     " $pro
    echo $0: output in " " $name.f " " ${name}.ps.gz
#    rm -f $mgfile $mgfigs
else 
  echo $0:" $mgfile not found in current directory"
  echo $0:" usage: place matrix.f and matrix.ps generated with MadGraph in this directory"
  echo $0:"        (NB! matrix.f should already have nexternal.inc replaced inline)"
fi
