// BranchelementalFSR.cc is a part of the VINCIA plug-in to the PYTHIA 8 generator.
// Copyright (C) 2016 P. Skands.
// VINCIA is licenced under the GNU GPL version 2.
// Please respect the MCnet Guidelines for Event Generator Authors and Users, 
//               http://www.montecarlonet.org/GUIDELINES

// Function definitions for the FSR & ISR Branchelementals class.

#include "Vincia/Branchelementals.h"

namespace Vincia {

//**********************************************************************

// BranchelementalFSR class member functions

//*********
// Simple print utility, showing the contents of the BranchelementalFSR

void BranchelementalFSR::list(ostream& os, bool header, bool footer) const { 
  if (header) {
    // Header.
    os << "\n --------  VINCIA FSR Dipole-Antenna Listing  --------------------------"
       << "------------------------------------------------------------ \n \n" 
       << "  sys       antenna type   pols    col     iL   mothers   iR"
       << "         m  Ord  Saved Trial Swap    Qtrial "
       << " nVeto nHull nHadr\n"
       << fixed << setprecision(3);
  }
  os << setw(5) << system<<" ";
  os << setw(9) << old1.name();
  os << setw(9) << old2.name()<<"  ";
  os << setw(2) << int(old1.pol()) <<" "<<setw(2)<< int(old2.pol())<<" ";
  os << setw(6) << old1.col()<<"  ";
  os << setw(5) << iL;
  os << setw(5) << iOld1 <<setw(5) << iOld2;
  os << setw(5) << iR ;
  os << num2str(m(),10);
  os << setw(5) << (unOrdering ? "n" : "y");
  int iWin = getTrialIndex();
  if (nTrialGenerators() >= 1 && iWin >= 0) {
    if (hasSavedTrial[iWin]) {
      os<< setw(13)<< trialGenPtrSav[iWin]->name();
      os << setw(5) << (isSwappedSav[iWin] ? "y" : "n");
      os<< num2str(scaleSav[iWin],10);
    }
  } else {
    os<<setw(13)<<"-";
    os<<setw(15)<<" ";
  }
  os << " "<<setw(6)<<nVeto;   
  os << " "<<setw(5)<<nHull;   
  os << " "<<setw(5)<<nHadr;   
  os << endl;   
  if (footer) {
    os << "\n --------  End VINCIA VinciaShower Dipole-Antenna Listing  ------------"
       << "-------------------------------------------------------------\n";
  }
}
  
  //**********************************************************************
  
  // ISRBranchelemental class member functions

  //**********************************************************************
  // Simple print utility, showing the contents of the ISRBranchelemental

  void BranchelementalISR::list(ostream& os, bool header, bool footer) const { 
    if (header) {
      os << " --------  VINCIA ISR Dipole-Antenna Listing  --------------\n";
      os << " syst iOld1 iOld2 isVal1 isVal2 col isII iL iR";
      os << " TrialGenerators\n";
    }
    os << "  " << system;
    os << "    " << iOld1;
    os << "     " << iOld2;
    os << "     " << (isVal1 ? "y" : "n");
    os << "      " << (isVal2 ? "y" : "n");
    os << "     " << col;
    os << "   " << (isII() ? "y" : "n");
    os << "   " << iL;
    os << "  " << iR;
    os << " ";
    for (int j=0; j<(int)trialGenPtrSav.size(); j++)
      os << trialGenPtrSav[j]->name() << " ";
    os << "\n";  
    if (footer) {
      os << " --------  End VINCIA SpaceShower Antenna Listing  ----------\n";
    }
  }
  
}
